@@ -6,6 +6,8 @@ CREATE TABLE IF NOT EXISTS products (
 	price    INT     NOT NULL,
 	stock    INT     NOT NULL,
 	freepost BOOLEAN NOT NULL DEFAULT FALSE,
+	model    TEXT,
+	brand    TEXT,
 	CONSTRAINT positive_stock CHECK (stock >= 0)
 );
 
